package flattimecollectionwrapper;

import com.github.anastr.flattimelib.CountDownTimerView;
import com.github.anastr.flattimelib.intf.OnTimeFinish;

import android.content.Context;
import android.view.ViewGroup;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.Hide;
import anywheresoftware.b4a.BA.Pixel;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.BALayout;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.keywords.Common.DesignerCustomView;
import anywheresoftware.b4a.objects.LabelWrapper;
import anywheresoftware.b4a.objects.PanelWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.BA.ActivityObject;

import anywheresoftware.b4a.BA.Events;

@ActivityObject
@Events(values={"timer_finished()"})
@Author("Github: Anas Altair, Wrapped by: Johan Schoeman")
//@Version(1.00f)
@ShortName("CountDownTimerView")
//@DependsOn(values={"com.android.support:support-v4"})
public class countdowntimerviewWrapper extends ViewWrapper<CountDownTimerView> implements DesignerCustomView {


	private BA ba;
	private String eventName;
    private CountDownTimerView cv;
	
	public void Initialize(BA ba, String EventName) {
		_initialize(ba, null, EventName);
	}

	@Hide
	public void _initialize(BA ba, Object activityClass, String EventName) {
		this.eventName = EventName.toLowerCase(BA.cul);
		this.ba = ba;
		cv = new CountDownTimerView(ba.context);
        this.setObject(cv);

        addListener1();

 	}
	
     private void addListener1() {	 
        cv.setOnTimeFinish(new OnTimeFinish() {
            @Override
            public void onFinish() {
              if (ba.subExists(eventName + "_timer_finished")) {
				ba.raiseEventFromDifferentThread(getObject(), null, 0, eventName + "_timer_finished", true, new Object[0] );
              }
            }
        });			
	} 
	
    /**
     * start the CountDownTimer.
     * this well stop CountDownTimer if it was running.
     * @param timeInMillisecond time in Millisecond.
     */
    public void start(long timeInMillisecond) {
        cv.start(timeInMillisecond);
		cv.invalidate();
    }

    /**
     * Ends the CountDownTimer. this will not call
     * {@link OnTimeFinish#onFinish()} method on
     * its listeners.
     */
    public void stop(){
        cv.stop();
        cv.invalidate();
    }

    /**
     * Pauses a running CountDownTimer. This method should only be called on the same thread on
     * which the CountDownTimer was started. If the CountDownTimer has not yet been {@link
     * #start(long)} started} or has since ended, then the call is ignored. Paused
     * CountDownTimer can be resumed by calling {@link #resume()}.
     *
     * @see #resume()
     */
    public void pause(){
        cv.pause();
		cv.invalidate();
    }

    /**
     * Resumes a paused CountDownTimer, causing the CountDownTimer to pick up where it left off
     * when it was paused. This method should only be called on the same thread on
     * which the CountDownTimer was started. Calls to resume() on an CountDownTimer that is
     * not currently paused will be ignored.
     *
     * @see #pause()
     */
    public void resume() {
        cv.resume();
		cv.invalidate();
    }

    /**
     * stop the CountDownTimer and start success Animation.
     * this will called {@link OnTimeFinish#onFinish()} method on
     * its listeners which set By {@link #setOnEndAnimationFinish(OnTimeFinish)}.
     *
     * <p>this method will change finish mode to Success.</p>
     * @see #setFinishMode(FinishMode)
     */
    public void success(){
        cv.success();
		cv.invalidate();
    }

    /**
     * @deprecated Use {@link #failure()}.
     */
    public void failed(){
        cv.failed();
		cv.invalidate();
    }

    /**
     * stop the CountDownTimer and start failure Animation.
     * this will called {@link OnTimeFinish#onFinish()} method on
     * its listeners which set By {@link #setOnEndAnimationFinish(OnTimeFinish)}.
     *
     * <p>this method will change finish mode to Failure.</p>
     * @see #setFinishMode(FinishMode)
     */
    public void failure(){
        cv.failure();
		cv.invalidate();
    }

    public void ready(){
        cv.ready();
		cv.invalidate();
    }


    public boolean isCountDownTimerRunning() {
        return cv.isCountDownTimerRunning();
    }

    /**
     * The time that has elapsed.
     *
     * @return ElapsedTime in millisecond.
     */
    public long getElapsedTime() {
        return cv.getElapsedTime();
    }

    /**
     * The full time that you set by {@link #start(long)} method.
     * Or default: 1000.
     *
     * @return FullTime in millisecond.
     */
    public long getFullTime() {
        return cv.getFullTime();
    }

    /**
     * Time that remains.
     *
     * @return RemainingTime in millisecond.
     */
    public long getRemainingTime() {
        return cv.getRemainingTime();
    }

    public int getFinishMode() {
        return cv.getFinishMode();
    }

    /**
     * to change End Animation, Once implemented the time.
     *
     * @param finish enum value {@link FinishMode}.
     */
	public int FinishMode_NoAnimation = -2;
	public int FinishMode_Faulure = -1;
	public int FinishMode_Default = 0;
	public int FinishMode_Success = 1;
    public void setFinishMode(int finish) {
		cv.setFinishMode(CountDownTimerView.FinishMode.NoAnimation);
		if (finish == -2) cv.setFinishMode(CountDownTimerView.FinishMode.NoAnimation);
		if (finish == -1) cv.setFinishMode(CountDownTimerView.FinishMode.Failure);
		if (finish == 0) cv.setFinishMode(CountDownTimerView.FinishMode.Default);
		if (finish == 1) cv.setFinishMode(CountDownTimerView.FinishMode.Success);
    }


    public void setIndicatorColor(int indicatorColor) {
        cv.setIndicatorColor(indicatorColor);
        cv.invalidate();
    }


    public void setRemainingTimeColor(int remainingTimeColor) {
        cv.setRemainingTimeColor(remainingTimeColor);
        cv.invalidate();
    }


    public void setStrokeColor(int strokeColor) {
        cv.setStrokeColor(strokeColor);
        cv.invalidate();
    }


    public void setElapsedTimeColor(int elapsedTimeColor) {
        cv.setElapsedTimeColor(elapsedTimeColor);
        cv.invalidate();
    }


    public void setStrokeWidth(float strokeWidth) {
        cv.setStrokeWidth(strokeWidth);
        cv.invalidate();
    }

    /**
     * Returns whether this CountDownTimer is currently in a paused state.
     *
     * @return True if the CountDownTimer is currently paused, false otherwise.
     *
     * @see #pause()
     * @see #resume()
     */
    public boolean isPaused() {
        return cv.isPaused();
    }

    public enum FinishMode {
        NoAnimation(-2),
        Failure(-1),
        Default(0),
        Success(1);

        int mode;
        FinishMode(int mode){
            this.mode = mode;
        }
    }	
	

	//programmatically add view
    @Hide
	public void AddToParent(ViewGroup Parent, @Pixel int left, @Pixel int top, @Pixel int width, @Pixel int height) {
		Parent.addView(cv, new BALayout.LayoutParams(left, top, width, height));
	}
	
	//this method cannot be hidden.
  
        
	public void DesignerCreateView(PanelWrapper base, LabelWrapper lw, anywheresoftware.b4a.objects.collections.Map props) {
		ViewGroup vg = (ViewGroup) base.getObject().getParent();
		AddToParent(vg, base.getLeft(), base.getTop(), base.getWidth(), base.getHeight());
		base.RemoveView();
		//set text properties
	}



	public void setLeft(int left)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.left = left;
		cv.getParent().requestLayout();
	}

	public int getLeft()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.left;
	}
	public void setTop(int top)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.top = top;
		cv.getParent().requestLayout();
	}
 
	public int getTop()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.top;
	}
	
	public void setWidth(int Width)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.width = Width;
		cv.getParent().requestLayout();
	}

	public int getWidth()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.width;
	}
	
	public void setHeight(int height)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.height = height;
		cv.getParent().requestLayout();
	}

	public int getHeight()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.height;
	}
		

   
}
