package flattimecollectionwrapper;

import com.github.anastr.flattimelib.FlatClockView;
import com.github.anastr.flattimelib.colors.Themes;
import com.github.anastr.flattimelib.intf.OnClockTick;

import android.content.Context;
import android.view.ViewGroup;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.Hide;
import anywheresoftware.b4a.BA.Pixel;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.BALayout;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.keywords.Common.DesignerCustomView;
import anywheresoftware.b4a.objects.LabelWrapper;
import anywheresoftware.b4a.objects.PanelWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.BA.ActivityObject;

import anywheresoftware.b4a.BA.Events;

@ActivityObject
@Events(values={"clock_time(hr As Int, mnt As Int, scnd As Int)"})
@Author("Github: Anas Altair, Wrapped by: Johan Schoeman")
@Version(1.00f)
@ShortName("FlatClockView")
//@DependsOn(values={"com.android.support:support-v4"})
public class flatclockviewWrapper extends ViewWrapper<FlatClockView> implements DesignerCustomView {


	private BA ba;
	private String eventName;
    private FlatClockView cv;
	
	public void Initialize(BA ba, String EventName) {
		_initialize(ba, null, EventName);
	}

	@Hide
	public void _initialize(BA ba, Object activityClass, String EventName) {
		this.eventName = EventName.toLowerCase(BA.cul);
		this.ba = ba;
		cv = new FlatClockView(ba.context);
        this.setObject(cv);

        addListener1();

 	}
	
    private void addListener1() {	
        cv.setOnClockTick(new OnClockTick() {
            @Override
            public void onTick() {
              if (ba.subExists(eventName + "_clock_time")) {
				ba.raiseEventFromDifferentThread(getObject(), null, 0, eventName + "_clock_time", true, new Object[] {cv.getMyHour(), cv.getMyMinute(), cv.getMySecond()});
              }
            }
        });			
	}
	

    /**
     * to set custom Time.
     *
     * @param hour should be between {0,11}
     *
     * @throws IllegalArgumentException if one of params out of range.
     */
    public void setTime_1(int hour){
        cv.setTime(hour, 0, 0);
		cv.invalidate();
    }

    /**
     * to set custom Time.
     *
     * @param hour should be between {0,11}
     * @param minute should be between {0,59}
     *
     * @throws IllegalArgumentException if one of params out of range.
     */
    public void setTime_2(int hour, int minute){
        cv.setTime(hour, minute, 0);
		cv.invalidate();
    }

    /**
     * to set custom Time.
     *
     * @param time it is "hh:mm:ss" should be Like "11:30:00".
     *
     * @throws IllegalArgumentException if one of params out of range,
     *             Or {@code time} doesn't Like "hh:mm:ss".
     * @throws NullPointerException if {@code time ==  null}
     * @throws NumberFormatException
     *             if {@code string} cannot be parsed as an integer value.
     */
    public void setTime_3(String time){
        cv.setTime(time);
		cv.invalidate();
    }

    /**
     * to set custom Time.
     *
     * @param hour should be between {0,11}
     * @param minute should be between {0,59}
     * @param second should be between {0,59}
     *
     * @throws IllegalArgumentException if one of params out of range
     */
    public void setTime_4(int hour, int minute, int second){
        cv.setTime(hour, minute, second);
        cv.invalidate();
    }

    public void setTimeToNow(){
        cv.setTimeToNow();
        cv.invalidate();
    }

    public void setMinIndicatorColor(int minIndicatorColor) {
        cv.setMinIndicatorColor(minIndicatorColor);
        cv.invalidate();
    }


    public void setHourIndicatorColor(int hourIndicatorColor) {
        cv.setHourIndicatorColor(hourIndicatorColor);
        cv.invalidate();
    }


    public void setSecIndicatorColor(int secIndicatorColor) {
        cv.setSecIndicatorColor(secIndicatorColor);
        cv.invalidate();
    }


    public void setBigMarkColor(int bigMarkColor) {
        cv.setBigMarkColor(bigMarkColor);
        cv.invalidate();
    }


    public void setSmallMarkColor(int smallMarkColor) {
        cv.setSmallMarkColor(smallMarkColor);
        cv.invalidate();
    }


    public void setBackgroundCircleColor(int backgroundCircleColor) {
        cv.setBackgroundCircleColor(backgroundCircleColor);
        cv.invalidate();
    }


    public void setWithBackground(boolean withBackground) {
        cv.setWithBackground(withBackground);
        cv.invalidate();
    }

	

	//programmatically add view
    @Hide
	public void AddToParent(ViewGroup Parent, @Pixel int left, @Pixel int top, @Pixel int width, @Pixel int height) {
		Parent.addView(cv, new BALayout.LayoutParams(left, top, width, height));
	}
	
	//this method cannot be hidden.
  
        
	public void DesignerCreateView(PanelWrapper base, LabelWrapper lw, anywheresoftware.b4a.objects.collections.Map props) {
		ViewGroup vg = (ViewGroup) base.getObject().getParent();
		AddToParent(vg, base.getLeft(), base.getTop(), base.getWidth(), base.getHeight());
		base.RemoveView();
		//set text properties
	}


	public void setLeft(int left)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.left = left;
		cv.getParent().requestLayout();
	}

	public int getLeft()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.left;
	}
	public void setTop(int top)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.top = top;
		cv.getParent().requestLayout();
	}
 
	public int getTop()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.top;
	}
	
	public void setWidth(int Width)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.width = Width;
		cv.getParent().requestLayout();
	}

	public int getWidth()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.width;
	}
	
	public void setHeight(int height)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.height = height;
		cv.getParent().requestLayout();
	}

	public int getHeight()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.height;
	}
	
   
}
