package flattimecollectionwrapper;

import com.github.anastr.flattimelib.HourGlassView;
import com.github.anastr.flattimelib.intf.OnTimeFinish;

import android.content.Context;
import android.view.ViewGroup;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Author;
import anywheresoftware.b4a.BA.Hide;
import anywheresoftware.b4a.BA.Pixel;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;
import anywheresoftware.b4a.BALayout;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.keywords.Common.DesignerCustomView;
import anywheresoftware.b4a.objects.LabelWrapper;
import anywheresoftware.b4a.objects.PanelWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.BA.ActivityObject;

import anywheresoftware.b4a.BA.Events;

@ActivityObject
@Events(values={"hour_glass_finished()"})
@Author("Github: Anas Altair, Wrapped by: Johan Schoeman")
//@Version(1.00f)
@ShortName("HourGlassView")
//@DependsOn(values={"com.android.support:support-v4"})
public class hourglassviewWrapper extends ViewWrapper<HourGlassView> implements DesignerCustomView {


	private BA ba;
	private String eventName;
    private HourGlassView cv;
	
	public void Initialize(BA ba, String EventName) {
		_initialize(ba, null, EventName);
	}

	@Hide
	public void _initialize(BA ba, Object activityClass, String EventName) {
		this.eventName = EventName.toLowerCase(BA.cul);
		this.ba = ba;
		cv = new HourGlassView(ba.context);
        this.setObject(cv);

        addListener1();

 	}
	
    private void addListener1() {	
        cv.setOnTimeFinish(new OnTimeFinish() {
            @Override
            public void onFinish() {
              if (ba.subExists(eventName + "_hour_glass_finished")) {
				ba.raiseEventFromDifferentThread(getObject(), null, 0, eventName + "_hour_glass_finished", true, new Object[0]);
              }
            }
        });
	} 
	
    public void start(long timeInMillisecond) {
        cv.start(timeInMillisecond);
        cv.invalidate();
    }

    /**
     * Ends the HourGlass. this will not call
     * {@link OnTimeFinish#onFinish()} method on
     * its listeners.
     */
    public void stop(){
        cv.stop();
        cv.invalidate();
    }

    public void pause() {
        cv.pause();
		cv.invalidate();
    }

    public void ready(){
        cv.ready();
        cv.invalidate();
    }

    public void flip() {
        cv.flip();
		cv.invalidate();
    }	
	
	
    /**
     * The time that has elapsed.
     *
     * @return ElapsedTime in millisecond.
     */
    public long getElapsedTime() {
        return cv.getElapsedTime();
    }

    /**
     * The full time that you set by {@link #start(long)} method.
     *
     * @return FullTime in millisecond.
     */
    public long getFullTime() {
        return cv.getFullTime();
    }

    /**
     * Time that remains.
     *
     * @return RemainingTime in millisecond.
     */
    public long getRemainingTime() {
        return cv.getRemainingTime();
    }

    /**
     * use if you need to check if HourGlass can flip or not.
     *
     * @return {@code true} if HourGlass doesn't flipping
     * or doesn't started yet, {@code false} otherwise.
     */
    public boolean canFlip() {
        return cv.canFlip();
    }

    /**
     * @return {@code true} if HourGlass doing flip, {@code false} otherwise.
     */
    public boolean isFlipping() {
        return cv.isFlipping();
    }


    public void setHourGlassColor(int hourGlassColor) {
        cv.setHourGlassColor(hourGlassColor);
        cv.invalidate();
    }


    public void setSandColor(int sandColor) {
        cv.setSandColor(sandColor);
        cv.invalidate();
    }	
	
	
	//programmatically add view
    @Hide
	public void AddToParent(ViewGroup Parent, @Pixel int left, @Pixel int top, @Pixel int width, @Pixel int height) {
		Parent.addView(cv, new BALayout.LayoutParams(left, top, width, height));
	}
	
	//this method cannot be hidden.
  
        
	public void DesignerCreateView(PanelWrapper base, LabelWrapper lw, anywheresoftware.b4a.objects.collections.Map props) {
		ViewGroup vg = (ViewGroup) base.getObject().getParent();
		AddToParent(vg, base.getLeft(), base.getTop(), base.getWidth(), base.getHeight());
		base.RemoveView();
		//set text properties
	}



	public void setLeft(int left)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.left = left;
		cv.getParent().requestLayout();
	}

	public int getLeft()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.left;
	}
	public void setTop(int top)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.top = top;
		cv.getParent().requestLayout();
	}
 
	public int getTop()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.top;
	}
	
	public void setWidth(int Width)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.width = Width;
		cv.getParent().requestLayout();
	}

	public int getWidth()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.width;
	}
	
	public void setHeight(int height)	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		lp.height = height;
		cv.getParent().requestLayout();
	}

	public int getHeight()	{
		BALayout.LayoutParams lp = (BALayout.LayoutParams)cv.getLayoutParams();
		return lp.height;
	}
	
   
}
